# APP_NAME_PLACEHOLDER

My new awesome homebrew application for the Nintendo Switch, created with [libnx](https://github.com/switchbrew/libnx).

[![generated_by nxstart](https://img.shields.io/badge/generated_by-nxstart-blue.svg)](https://github.com/roedesh/nxstart)

## Features

...

## Getting Started

Make sure you have [DevKitA64](https://devkitpro.org/) installed. Installations can be found on their website.
For Unix-like platforms, it is recommended to use [Pacman](https://github.com/devkitPro/pacman) for installing the
required tools.

### Running the app

Run `make` inside this folder. Put the `.nro` file you just created on your SD card and launch it.

## Author

APP_AUTHOR_PLACEHOLDER
